.. _reporting_ref:

:mod:`nilearn.reporting`: Reporting Functions
=============================================

.. automodule:: nilearn.reporting
   :no-members:
   :no-inherited-members:

Classes
-------

.. currentmodule:: nilearn.reporting

.. autosummary::
   :toctree: generated/
   :template: class.rst

   HTMLReport

Functions
---------

.. currentmodule:: nilearn.reporting

.. autosummary::
   :toctree: generated/
   :template: function.rst

   get_clusters_table
   make_glm_report


.. toctree::

   generated_reports/glm_reports_examples.rst
